@@ -54,8 +54,6 @@ pref("general.useragent.contentlocale", "chrome://navigator-region/locale/region
 
 pref("general.config.obscure_value", 13); // for MCD .cfg files
 
-pref("backups.number_of_prefs_copies", 1);
-
 pref("browser.cache.disk.enable",           true);
 pref("browser.cache.disk.capacity",         51200);
 pref("browser.cache.memory.enable",         true);
@@ -64,6 +62,9 @@ pref("browser.cache.memory.enable",         true);
 pref("browser.cache.disk_cache_ssl",        false);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
 pref("browser.cache.check_doc_frequency",   3);
+// Fastback caching - if this pref is negative, then we calculate the number
+// of content viewers to cache based on the amount of available memory.
+pref("browser.sessionhistory.max_total_viewers", -1);
 
 pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always
 pref("browser.display.use_document_colors", true);
@@ -97,14 +98,24 @@ pref("browser.helperApps.neverAsk.openFile", "");
 pref("browser.chrome.toolbar_tips",         true);
 // 0 = Pictures Only, 1 = Text Only, 2 = Pictures and Text
 pref("browser.chrome.toolbar_style",        2);
+// max image size for which it is placed in the tab icon for tabbrowser.
+// if 0, no images are used for tab icons for image documents.
+pref("browser.chrome.image_icons.max_size", 1024);
 
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
+
+//@line 110 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
+// On OS X, we use Full Keyboard Access system preference,
+// unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
+pref("accessibility.tabfocus_applies_to_xul", false);
+//@line 121 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
 pref("accessibility.accesskeycausesactivation", true);
@@ -131,12 +142,8 @@ pref("browser.forms.submit.backwards_compatible", true);
 // Tab browser preferences.
 pref("browser.tabs.autoHide", true);
 pref("browser.tabs.forceHide", false);
-pref("browser.tabs.loadInBackground", false);
-pref("browser.tabs.opentabfor.middleclick", false);
-pref("browser.tabs.opentabfor.urlbar", false);
-pref("browser.tabs.opentabfor.windowopen", false);
-pref("browser.tabs.opentabfor.bookmarks", false);
 pref("browser.tabs.warnOnClose", true);
+pref("browser.tabs.warnOnCloseOther", true);
 // 0 = append, 1 = replace
 pref("browser.tabs.loadGroup", 1);
 
@@ -148,12 +155,6 @@ pref("browser.tabs.loadGroup", 1);
 pref("browser.tabs.loadOnNewTab", 0);
 pref("browser.windows.loadOnNewWindow", 1);
 
-// link handling in tabbed browsers. values from nsIBrowserDOMWindow.
-pref("browser.link.open_external", 1);
-pref("browser.link.open_newwindow", 2);
-pref("browser.link.open_newwindow.ui", 3); // prefs UI version
-pref("browser.link.open_newwindow.restriction", 0); // values from GlobalWindow
-
 // view source
 pref("view_source.syntax_highlight", true);
 pref("view_source.wrap_long_lines", false);
@@ -266,19 +267,30 @@ pref("capability.policy.default.Navigator.preferenceinternal.set", "UniversalPre
 
 pref("capability.policy.default.Window.blur.get", "allAccess");
 pref("capability.policy.default.Window.close.get", "allAccess");
-pref("capability.policy.default.Window.closed", "allAccess");
+pref("capability.policy.default.Window.closed.get", "allAccess");
 pref("capability.policy.default.Window.Components", "allAccess");
-pref("capability.policy.default.Window.document", "allAccess");
+pref("capability.policy.default.Window.document.get", "allAccess");
 pref("capability.policy.default.Window.focus.get", "allAccess");
-pref("capability.policy.default.Window.frames", "allAccess");
-pref("capability.policy.default.Window.history", "allAccess");
-pref("capability.policy.default.Window.length", "allAccess");
+pref("capability.policy.default.Window.frames.get", "allAccess");
+pref("capability.policy.default.Window.history.get", "allAccess");
+pref("capability.policy.default.Window.length.get", "allAccess");
 pref("capability.policy.default.Window.location", "allAccess");
-pref("capability.policy.default.Window.opener", "allAccess");
-pref("capability.policy.default.Window.parent", "allAccess");
-pref("capability.policy.default.Window.self", "allAccess");
-pref("capability.policy.default.Window.top", "allAccess");
-pref("capability.policy.default.Window.window", "allAccess");
+pref("capability.policy.default.Window.opener.get", "allAccess");
+pref("capability.policy.default.Window.parent.get", "allAccess");
+pref("capability.policy.default.Window.self.get", "allAccess");
+pref("capability.policy.default.Window.top.get", "allAccess");
+pref("capability.policy.default.Window.window.get", "allAccess");
+
+pref("capability.policy.default.XULControllers.commandDispatcher", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerForCommand", "noAccess");
+pref("capability.policy.default.XULControllers.insertControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.removeControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.appendController", "noAccess");
+pref("capability.policy.default.XULControllers.removeController", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerId", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerById", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerCount", "noAccess");
 
 // Restrictions on the DOM for mail/news - see bugs 66938 and 84545
 pref("capability.policy.mailnews.sites", "mailbox: imap: news:");
@@ -324,6 +336,7 @@ pref("capability.policy.mailnews.Window.screenY.set", "noAccess");
 pref("capability.policy.mailnews.Window.sizeToContent", "noAccess");
 pref("capability.policy.mailnews.document.load", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.channel", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.getInterface", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.responseXML", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.responseText", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.status", "noAccess");
@@ -341,8 +354,8 @@ pref("capability.policy.mailnews.XMLHttpRequest.onerror", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.onreadystatechange", "noAccess");
 pref("capability.policy.mailnews.XMLSerializer.serializeToString", "noAccess");
 pref("capability.policy.mailnews.XMLSerializer.serializeToStream", "noAccess");
-pref("capability.policy.mailnews.DOMParser,parseFromString", "noAccess");
-pref("capability.policy.mailnews.DOMParser,parseFromStream", "noAccess");
+pref("capability.policy.mailnews.DOMParser.parseFromString", "noAccess");
+pref("capability.policy.mailnews.DOMParser.parseFromStream", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.transportURI", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.verifySourceHeader", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.invoke", "noAccess");
@@ -391,6 +404,7 @@ pref("capability.policy.mailnews.WebServiceProxyFactory.onError", "noAccess");
 
 // XMLExtras
 pref("capability.policy.default.XMLHttpRequest.channel", "noAccess");
+pref("capability.policy.default.XMLHttpRequest.getInterface", "noAccess");
 pref("capability.policy.default.DOMParser.parseFromStream", "noAccess");
 
 // Clipboard
@@ -413,7 +427,7 @@ pref("dom.disable_window_open_feature.menubar",     false);
 pref("dom.disable_window_open_feature.scrollbars",  false);
 pref("dom.disable_window_open_feature.resizable",   false);
 pref("dom.disable_window_open_feature.minimizable", false);
-pref("dom.disable_window_open_feature.status",      false);
+pref("dom.disable_window_open_feature.status",      true);
 
 pref("dom.allow_scripts_to_close_windows",          false);
 
@@ -422,6 +436,12 @@ pref("dom.popup_maximum",                           20);
 pref("dom.popup_allowed_events", "change click dblclick mouseup reset submit");
 pref("dom.disable_open_click_delay", 1000);
 
+// Disable popups from plugins by default
+//   0 = openAllowed
+//   1 = openControlled
+//   2 = openAbused
+pref("privacy.popups.disable_from_plugins", 2);
+
 pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
@@ -429,7 +449,6 @@ pref("javascript.allow.mailnews",           false);
 pref("javascript.options.strict",           false);
 
 // advanced prefs
-pref("advanced.always_load_images",         true);
 pref("security.enable_java",                true);
 pref("advanced.mailftp",                    false);
 pref("image.animation_mode",                "normal");
@@ -454,7 +473,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-pref("network.protocol-handler.external.help", false);
+//@line 482 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -522,10 +541,6 @@ pref("network.http.max-persistent-connections-per-proxy", 4);
 // max-connections or max-connections-per-server has also been reached.
 pref("network.http.request.max-start-delay", 10);
 
-// http specific network timeouts (XXX currently unused)
-pref("network.http.connect.timeout",  30);	// in seconds
-pref("network.http.request.timeout", 120);	// in seconds
-
 // Headers
 pref("network.http.accept.default", "text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5");
 pref("network.http.sendRefererHeader",      2); // 0=don't send any, 1=send only on clicks, 2=send on image requests as well
@@ -556,7 +571,51 @@ pref("network.enableIDN", true);
 // This preference, if true, causes all UTF-8 domain names to be normalized to
 // punycode.  The intention is to allow UTF-8 domain names as input, but never
 // generate them from punycode.
-pref("network.IDN_show_punycode", true);
+pref("network.IDN_show_punycode", false);
+
+// TLDs with "network.IDN.whitelist.tld" explicitly set to true are treated as 
+// IDN-safe. Otherwise, they're treated as unsafe and punycode will be used
+// for displaying them in the UI (e.g. URL bar). Note that these preferences
+// are referred to ONLY when "network.IDN_show_punycode" is false. In other
+// words, all IDNs will be shown in punycode if "network.IDN_show_punycode"
+// is true.
+
+// ccTLDs
+pref("network.IDN.whitelist.ac", true);
+pref("network.IDN.whitelist.at", true);
+pref("network.IDN.whitelist.br", true);
+pref("network.IDN.whitelist.ch", true);
+pref("network.IDN.whitelist.cl", true);
+pref("network.IDN.whitelist.cn", true);
+pref("network.IDN.whitelist.de", true);
+pref("network.IDN.whitelist.dk", true);
+pref("network.IDN.whitelist.fi", true);
+pref("network.IDN.whitelist.gr", true);
+pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.io", true);
+pref("network.IDN.whitelist.is", true);
+pref("network.IDN.whitelist.jp", true);
+pref("network.IDN.whitelist.kr", true);
+pref("network.IDN.whitelist.li", true);
+pref("network.IDN.whitelist.lt", true);
+pref("network.IDN.whitelist.no", true);
+pref("network.IDN.whitelist.se", true);
+pref("network.IDN.whitelist.sh", true);
+pref("network.IDN.whitelist.th", true);
+pref("network.IDN.whitelist.tm", true);
+pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.vn", true);
+
+// non-ccTLDs
+pref("network.IDN.whitelist.info", true);
+pref("network.IDN.whitelist.museum", true);
+pref("network.IDN.whitelist.org", true);
+
+// If a domain includes any of the following characters, it may be a spoof 
+// attempt and so we always display the domain name as punycode. This would 
+// override the settings "network.IDN_show_punycode" and 
+// "network.IDN.whitelist.*".
+pref("network.IDN.blacklist_chars", "\u0020\u00A0\u00BC\u00BD\u01C3\u0337\u0338\u05C3\u05F4\u06D4\u0702\u115F\u1160\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u200B\u2024\u2027\u2028\u2029\u202F\u2039\u203A\u2044\u205F\u2154\u2155\u2156\u2159\u215A\u215B\u215F\u2215\u23AE\u29F6\u29F8\u2AFB\u2AFD\u2FF0\u2FF1\u2FF2\u2FF3\u2FF4\u2FF5\u2FF6\u2FF7\u2FF8\u2FF9\u2FFA\u2FFB\u3000\u3002\u3014\u3015\u3033\u3164\u321D\u321E\u33AE\u33AF\u33C6\u33DF\uFE14\uFE15\uFE3F\uFE5D\uFE5E\uFEFF\uFF0E\uFF0F\uFF61\uFFA0\uFFF9\uFFFA\uFFFB\uFFFC\uFFFD");
 
 // This preference specifies a list of domains for which DNS lookups will be
 // IPv4 only. Works around broken DNS servers which can't handle IPv6 lookups
@@ -577,8 +636,10 @@ pref("network.standard-url.encode-utf8", false);
 // Idle timeout for ftp control connections - 5 minute default
 pref("network.ftp.idleConnectionTimeout", 300);
 
-// directory listing format - constants are defined in nsIDirectoryListing.idl
-// Do not set this to 0...
+// directory listing format
+// 2: HTML
+// 3: XUL directory viewer
+// all other values are treated like 2
 pref("network.dir.format", 2);
 
 // enables the prefetch service (i.e., prefetching of <link rel="next"> URLs).
@@ -598,21 +659,38 @@ pref("network.negotiate-auth.trusted-uris", "");
 // This list controls which URIs can support delegation.
 pref("network.negotiate-auth.delegation-uris", "");
 
+// Allow SPNEGO by default when challenged by a proxy server.
+pref("network.negotiate-auth.allow-proxies", true);
+
+// Path to a specific gssapi library
+pref("network.negotiate-auth.gsslib", "");
+
+// Specify if the gss lib comes standard with the OS
+pref("network.negotiate-auth.using-native-gsslib", true);
+
+//@line 682 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
-// Window's domain logon.  By default, this is enabled for proxy servers.
-// The trusted-uris pref follows the format of the trusted-uris pref for
-// negotiate authentication.
+// Window's domain logon.  The trusted-uris pref follows the format of the
+// trusted-uris pref for negotiate authentication.
 pref("network.automatic-ntlm-auth.allow-proxies", true);
 pref("network.automatic-ntlm-auth.trusted-uris", "");
 
+// This preference controls whether or not the LM hash will be included in
+// response to a NTLM challenge.  By default, this is disabled since servers
+// should almost never need the LM hash, and the LM hash is what makes NTLM
+// authentication less secure.  See bug 250691 for further details.
+// NOTE: automatic-ntlm-auth which leverages the OS-provided NTLM
+//       implementation will not be affected by this preference.
+pref("network.ntlm.send-lm-response", false);
 
 // sspitzer:  change this back to "news" when we get to beta.
 // for now, set this to news.mozilla.org because you can only
 // post to the server specified by this pref.
 pref("network.hosts.nntp_server",           "news.mozilla.org");
 
-pref("network.image.imageBehavior",         0); // 0-Accept, 1-dontAcceptForeign, 2-dontUse
+pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 pref("network.image.warnAboutImages",       false);
 pref("network.proxy.autoconfig_url",        "");
 pref("network.proxy.type",                  0);
@@ -627,9 +705,11 @@ pref("network.proxy.ssl_port",              0);
 pref("network.proxy.socks",                 "");
 pref("network.proxy.socks_port",            0);
 pref("network.proxy.socks_version",         5);
+pref("network.proxy.socks_remote_dns",      false);
 pref("network.proxy.no_proxies_on",         "localhost, 127.0.0.1");
+pref("network.proxy.failover_timeout",      1800); // 30 minutes
 pref("network.online",                      true); //online/offline
-pref("network.cookie.cookieBehavior",       3); // 0-Accept, 1-dontAcceptForeign, 2-dontUse, 3-p3p
+pref("network.cookie.cookieBehavior",       0); // 0-Accept, 1-dontAcceptForeign, 2-dontUse, 3-p3p
 pref("network.cookie.disableCookieForMailNews", true); // disable all cookies for mail
 pref("network.cookie.lifetimePolicy",       0); // accept normally, 1-askBeforeAccepting, 2-acceptForSession,3-acceptForNDays
 pref("network.cookie.alwaysAcceptSessionCookies", false);
@@ -637,7 +717,7 @@ pref("network.cookie.prefsMigrated",        false);
 pref("network.cookie.lifetime.days",        90);
 
 // The following default value is for p3p medium mode.
-// See extensions/cookie/resources/content/p3p.xul for the definitions of low/medium/hi
+// See xpfe/components/permissions/content/cookieP3P.xul for the definitions of low/medium/hi
 pref("network.cookie.p3p",                  "ffffaaaa");
 pref("network.cookie.p3plevel",             1); // 0=low, 1=medium, 2=high, 3=custom
 
@@ -645,10 +725,14 @@ pref("network.enablePad",                   false); // Allow client to do proxy
 pref("converter.html2txt.structs",          true); // Output structured phrases (strong, em, code, sub, sup, b, i, u)
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
+pref("ime.password.onFocus.dontCare",       false);
+pref("ime.password.onBlur.dontCare",        false);
+
 pref("intl.accept_languages",               "chrome://navigator/locale/navigator.properties");
 pref("intl.accept_charsets",                "iso-8859-1,*,utf-8");
 pref("intl.collationOption",                "chrome://navigator-platform/locale/navigator.properties");
 pref("intl.menuitems.alwaysappendaccesskeys","chrome://navigator/locale/navigator.properties");
+pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://navigator/locale/navigator.properties");
 pref("intl.charsetmenu.browser.static",     "chrome://navigator/locale/navigator.properties");
 pref("intl.charsetmenu.browser.more1",      "chrome://navigator/locale/navigator.properties");
 pref("intl.charsetmenu.browser.more2",      "chrome://navigator/locale/navigator.properties");
@@ -706,12 +790,21 @@ pref("mousewheel.withnokey.sysnumlines",true);
 pref("mousewheel.withcontrolkey.action",0);
 pref("mousewheel.withcontrolkey.numlines",1);
 pref("mousewheel.withcontrolkey.sysnumlines",true);
+// mousewheel.withshiftkey, see the Mac note below.
 pref("mousewheel.withshiftkey.action",0);
 pref("mousewheel.withshiftkey.numlines",1);
 pref("mousewheel.withshiftkey.sysnumlines",true);
 pref("mousewheel.withaltkey.action",2);
 pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withaltkey.sysnumlines",false);
+pref("mousewheel.withmetakey.action",0);
+pref("mousewheel.withmetakey.numlines",1);
+pref("mousewheel.withmetakey.sysnumlines",true);
+
+// on platforms where scroll messages differ between horizontal scroll
+// and back/forward button events we can activate them by default
+//@line 851 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+// disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
 pref("mousewheel.horizscroll.withnokey.sysnumlines",false);
@@ -724,6 +817,10 @@ pref("mousewheel.horizscroll.withshiftkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withaltkey.action",2);
 pref("mousewheel.horizscroll.withaltkey.numlines",-1);
 pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
+pref("mousewheel.horizscroll.withmetakey.action",2);
+pref("mousewheel.horizscroll.withmetakey.numlines",-1);
+pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
+//@line 868 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -793,7 +890,6 @@ pref("bidi.support", 1);
 // 2 = defaultcharactersetBidi
 pref("bidi.characterset", 1);
 
-pref("bidi.browser.ui", false);
 
 // used for double-click word selection behavior. Win will override.
 pref("layout.word_select.eat_space_to_next_word", false);
@@ -855,10 +951,17 @@ pref("editor.positioning.offset",            0);
 
 pref("dom.max_script_run_time", 5);
 
+pref("svg.enabled", true);
 
+//@line 1331 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
+//@line 1518 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
+//@line 1707 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
+//@line 1788 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+
+//@line 1791 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -909,8 +1012,6 @@ pref("applications.telnet", "xterm -e telnet %h %p");
 pref("applications.tn3270", "xterm -e tn3270 %h");
 pref("applications.rlogin", "xterm -e rlogin %h");
 pref("applications.rlogin_with_user", "xterm -e rlogin %h -l %u");
-pref("applications.tmp_dir", "/tmp");
-// On Solaris/IRIX, this should be "lp"
 pref("print.print_command", "lpr ${MOZ_PRINTER_NAME:+'-P'}${MOZ_PRINTER_NAME}");
 pref("print.printer_list", ""); // list of printers, separated by spaces
 pref("print.print_reversed", false);
@@ -936,107 +1037,124 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-pref("font.name.serif.el", "misc-fixed-iso8859-7");
-pref("font.name.sans-serif.el", "misc-fixed-iso8859-7");
-pref("font.name.monospace.el", "misc-fixed-iso8859-7");
+//@line 1867 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-pref("font.name.serif.he", "misc-fixed-iso8859-8");
-pref("font.name.sans-serif.he", "misc-fixed-iso8859-8");
-pref("font.name.monospace.he", "misc-fixed-iso8859-8");
+pref("font.name.serif.el", "serif");
+pref("font.name.sans-serif.el", "sans-serif");
+pref("font.name.monospace.el", "monospace");
 
-pref("font.name.serif.ja", "jis-fixed-jisx0208.1983-0");
-pref("font.name.sans-serif.ja", "jis-fixed-jisx0208.1983-0");
-pref("font.name.monospace.ja", "jis-fixed-jisx0208.1983-0");
+pref("font.name.serif.he", "serif");
+pref("font.name.sans-serif.he", "sans-serif");
+pref("font.name.monospace.he", "monospace");
 
-pref("font.name.serif.ko", "daewoo-mincho-ksc5601.1987-0");
-pref("font.name.sans-serif.ko", "daewoo-mincho-ksc5601.1987-0");
-pref("font.name.monospace.ko", "daewoo-mincho-ksc5601.1987-0");
+pref("font.name.serif.ja", "serif");
+pref("font.name.sans-serif.ja", "sans-serif");
+pref("font.name.monospace.ja", "monospace");
+
+pref("font.name.serif.ko", "serif");
+pref("font.name.sans-serif.ko", "sans-serif");
+pref("font.name.monospace.ko", "monospace");
 
 // th
 
-pref("font.name.serif.tr", "adobe-times-iso8859-9");
-pref("font.name.sans-serif.tr", "adobe-helvetica-iso8859-9");
-pref("font.name.monospace.tr", "adobe-courier-iso8859-9");
+pref("font.name.serif.tr", "Times");
+pref("font.name.sans-serif.tr", "Helvetica");
+pref("font.name.monospace.tr", "Courier");
 
-pref("font.name.serif.x-baltic", "b&h-lucidux serif-iso8859-4");
-pref("font.name.sans-serif.x-baltic", "b&h-lucidux sans-iso8859-4");
-pref("font.name.monospace.x-baltic", "b&h-lucidux mono-iso8859-4");
+pref("font.name.serif.x-baltic", "serif");
+pref("font.name.sans-serif.x-baltic", "sans-serif");
+pref("font.name.monospace.x-baltic", "monospace");
 
-pref("font.name.serif.x-central-euro", "adobe-times-iso8859-2");
-pref("font.name.sans-serif.x-central-euro", "adobe-helvetica-iso8859-2");
-pref("font.name.monospace.x-central-euro", "adobe-courier-iso8859-2");
+pref("font.name.serif.x-central-euro", "Times");
+pref("font.name.sans-serif.x-central-euro", "Helvetica");
+pref("font.name.monospace.x-central-euro", "Courier");
 
-pref("font.name.serif.x-cyrillic", "cronyx-times-koi8-r");
-pref("font.name.sans-serif.x-cyrillic", "cronyx-helvetica-koi8-r");
-pref("font.name.monospace.x-cyrillic", "cronyx-courier-koi8-r");
+pref("font.name.serif.x-cyrillic", "serif");
+pref("font.name.sans-serif.x-cyrillic", "sans-serif");
+pref("font.name.monospace.x-cyrillic", "monospace");
 
-pref("font.name.serif.x-unicode", "adobe-times-iso8859-1");
-pref("font.name.sans-serif.x-unicode", "adobe-helvetica-iso8859-1");
-pref("font.name.monospace.x-unicode", "adobe-courier-iso8859-1");
+pref("font.name.serif.x-unicode", "Times");
+pref("font.name.sans-serif.x-unicode", "Helvetica");
+pref("font.name.monospace.x-unicode", "Courier");
 
-pref("font.name.serif.x-user-def", "adobe-times-iso8859-1");
-pref("font.name.sans-serif.x-user-def", "adobe-helvetica-iso8859-1");
-pref("font.name.monospace.x-user-def", "adobe-courier-iso8859-1");
+pref("font.name.serif.x-user-def", "Times");
+pref("font.name.sans-serif.x-user-def", "Helvetica");
+pref("font.name.monospace.x-user-def", "Courier");
 
-pref("font.name.serif.x-western", "adobe-times-iso8859-1");
-pref("font.name.sans-serif.x-western", "adobe-helvetica-iso8859-1");
-pref("font.name.monospace.x-western", "adobe-courier-iso8859-1");
+pref("font.name.serif.x-western", "Times");
+pref("font.name.sans-serif.x-western", "Helvetica");
+pref("font.name.monospace.x-western", "Courier");
 
-pref("font.name.serif.zh-CN", "isas-song ti-gb2312.1980-0");
-pref("font.name.sans-serif.zh-CN", "isas-song ti-gb2312.1980-0");
-pref("font.name.monospace.zh-CN", "isas-song ti-gb2312.1980-0");
+pref("font.name.serif.zh-CN", "serif");
+pref("font.name.sans-serif.zh-CN", "sans-serif");
+pref("font.name.monospace.zh-CN", "monospace");
 
 // ming_uni.ttf (HKSCS-2001) 
 // http://www.info.gov.hk/digital21/eng/hkscs/download/uime.exe
-pref("font.name.serif.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
-pref("font.name.sans-serif.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
-pref("font.name.monospace.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
+pref("font.name.serif.zh-HK", "serif");
+pref("font.name.sans-serif.zh-HK", "sans-serif");
+pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
+//@line 1986 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
-pref("font.default", "serif");
+pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
 pref("font.size.fixed.ar", 12);
 
+pref("font.default.el", "serif");
 pref("font.size.variable.el", 16);
 pref("font.size.fixed.el", 12);
 
+pref("font.default.he", "sans-serif");
 pref("font.size.variable.he", 16);
 pref("font.size.fixed.he", 12);
 
+pref("font.default.ja", "sans-serif");
 pref("font.size.variable.ja", 16);
 pref("font.size.fixed.ja", 16);
 
+pref("font.default.ko", "sans-serif");
 pref("font.size.variable.ko", 16);
 pref("font.size.fixed.ko", 16);
 
+pref("font.default.th", "serif");
 pref("font.size.variable.th", 16);
 pref("font.size.fixed.th", 12);
 
+pref("font.default.tr", "serif");
 pref("font.size.variable.tr", 16);
 pref("font.size.fixed.tr", 12);
 
+pref("font.default.x-baltic", "serif");
 pref("font.size.variable.x-baltic", 16);
 pref("font.size.fixed.x-baltic", 12);
 
+pref("font.default.x-central-euro", "serif");
 pref("font.size.variable.x-central-euro", 16);
 pref("font.size.fixed.x-central-euro", 12);
 
+pref("font.default.x-cyrillic", "serif");
 pref("font.size.variable.x-cyrillic", 16);
 pref("font.size.fixed.x-cyrillic", 12);
 
+pref("font.default.x-unicode", "serif");
 pref("font.size.variable.x-unicode", 16);
 pref("font.size.fixed.x-unicode", 12);
 
+pref("font.default.x-western", "serif");
 pref("font.size.variable.x-western", 16);
 pref("font.size.fixed.x-western", 12);
 
+pref("font.default.zh-CN", "sans-serif");
 pref("font.size.variable.zh-CN", 16);
 pref("font.size.fixed.zh-CN", 16);
 
+pref("font.default.zh-TW", "sans-serif");
 pref("font.size.variable.zh-TW", 16);
 pref("font.size.fixed.zh-TW", 16);
 
+pref("font.default.zh-HK", "sans-serif");
 pref("font.size.variable.zh-HK", 16);
 pref("font.size.fixed.zh-HK", 16);
 
@@ -1196,6 +1314,11 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
+//@line 2206 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
+//@line 2274 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
+//@line 2300 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
+
+//@line 2320 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/modules/libpref/src/init/all.js"
 
