@@ -1,3 +1,4 @@
+//@line 40 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mail3PaneWindowCommands.js"
 
 var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
 var gMessengerBundle = document.getElementById("bundle_messenger");
@@ -40,7 +41,7 @@ var FolderPaneController =
       var folderTree = GetFolderTree();
       var startIndex = {};
       var endIndex = {};
-      folderTree.treeBoxObject.selection.getRangeAt(0, startIndex, endIndex);
+      folderTree.view.selection.getRangeAt(0, startIndex, endIndex);
       if (startIndex.value >= 0) {
         var canDeleteThisFolder;
 				var specialFolder = null;
@@ -132,6 +133,7 @@ var DefaultController =
 			case "cmd_previousMsg":
 			case "cmd_previousUnreadMsg":
 			case "cmd_previousFlaggedMsg":
+      case "cmd_goStartPage":
 			case "cmd_viewAllMsgs":
 			case "cmd_viewUnreadMsgs":
       case "cmd_viewThreadsWithUnread":
@@ -231,9 +233,9 @@ var DefaultController =
           gDBView.getCommandStatus(nsMsgViewCommandType.junk, enabled, checkStatus);
         return enabled.value;
       case "cmd_killThread":
-        return GetNumSelectedMessages() == 1;
+        return GetNumSelectedMessages() > 0;
       case "cmd_watchThread":
-        if ((GetNumSelectedMessages() == 1) && gDBView)
+        if (gDBView)
           gDBView.getCommandStatus(nsMsgViewCommandType.toggleThreadWatched, enabled, checkStatus);
         return enabled.value;
       case "cmd_createFilterFromPopup":
@@ -319,6 +321,8 @@ var DefaultController =
       case "cmd_previousMsg":
       case "cmd_previousUnreadMsg":
         return IsViewNavigationItemEnabled();
+      case "cmd_goStartPage":
+        return pref.getBoolPref("mailnews.start_page.enabled") && !IsMessagePaneCollapsed();
       case "cmd_markAllRead":
       case "cmd_markReadByDate":
         return IsFolderSelected();
@@ -441,20 +445,14 @@ var DefaultController =
 			case "cmd_delete":
          // if the user deletes a message before its mark as read timer goes off, we should mark it as read
          // this ensures that we clear the biff indicator from the system tray when the user deletes the new message
-        if (gMarkViewedMessageAsReadTimer) 
-        {
+        if (gMarkViewedMessageAsReadTimer)
           MarkCurrentMessageAsRead();
-          ClearPendingReadTimer();
-        }
         SetNextMessageAfterDelete();
         gDBView.doCommand(nsMsgViewCommandType.deleteMsg);
 				break;
 			case "cmd_shiftDelete":
         if (gMarkViewedMessageAsReadTimer)
-        {
           MarkCurrentMessageAsRead();
-          ClearPendingReadTimer();
-        }
         SetNextMessageAfterDelete();
         gDBView.doCommand(nsMsgViewCommandType.deleteNoTrash);
 				break;
@@ -488,6 +486,10 @@ var DefaultController =
 			case "cmd_previousFlaggedMsg":
 				MsgPreviousFlaggedMessage();
 				break;
+      case "cmd_goStartPage":
+        HideMessageHeaderPane();
+        loadStartPage();
+        break;
 			case "cmd_viewAllMsgs":
       case "cmd_viewThreadsWithUnread":
       case "cmd_viewWatchedThreadsWithUnread":
@@ -790,7 +792,7 @@ function IsSendUnsentMsgsEnabled(folderResource)
 function IsRenameFolderEnabled()
 {
     var folderTree = GetFolderTree();
-    var selection = folderTree.treeBoxObject.selection;
+    var selection = folderTree.view.selection;
     if (selection.count == 1)
     {
         var startIndex = {};
@@ -839,7 +841,7 @@ function IsPropertiesEnabled(command)
    if (IsFakeAccount())
      return false;
 
-   var selection = folderTree.treeBoxObject.selection;
+   var selection = folderTree.view.selection;
    return (selection.count == 1);
 }
 
@@ -851,7 +853,7 @@ function IsViewNavigationItemEnabled()
 function IsFolderSelected()
 {
     var folderTree = GetFolderTree();
-    var selection = folderTree.treeBoxObject.selection;
+    var selection = folderTree.view.selection;
     if (selection.count == 1)
     {
         var startIndex = {};
@@ -1007,7 +1009,8 @@ function SearchBarToggled()
   }
 
   for (var currentNode = top.document.commandDispatcher.focusedElement; currentNode; currentNode = currentNode.parentNode) {
-    if (currentNode.getAttribute("hidden") == "true") {
+    // But skip the last node, which is a XULDocument.
+    if ((currentNode instanceof XULElement) && currentNode.hidden) {
       SetFocusThreadPane();
       return;
     }
